# 2. Digital bodies

![](../images/wk02_nike.jpg)

*The mannequin at Nike's London flagship store that sparked outrage earlier this year. Image by Nike.*

For this weeks' assignment, I've done the research and practice work without separating them, to see if I can keep the thinking and doing more connected. I loved the week's theme of not thinking of the body as a white canvas, but instead understand how any perception of, or idea about bodies is already cultural and, if I may add: implicated in body politics. It resulted in three experiments and a realized physical model made out of paper. In summary I have:

1. Generated a 3D mesh of a body using *MakeHuman*
2. Generated a 3D mesh of a body by *scanning*, using *SizeStream*
3. Manipulated a 3D mesh (using *Rhinoceros*)
	* by chopping limbs using the *MeshBoolean* commands
	* by rotating and making repetitions
	* by adding a platform using the *MeshBooleanUnion* command
	* by reducing the amount of faces and vertices of the mesh
4. Translating the design into flat pieces using *Slicer*
5. Cut the designs using a *laser cutter* and assembled a paper model.
 

## Part 1: Digital bodies are standardized bodies

Let's start here: How is it possible, that in 2019, a sports wear brand like Nike manages to spark a total online outrage by introducing bigger mannequins at their London flagship store? The consumerist glamour fantasy hasn't been real for a long time now! Walk out of the Nike store, onto the highstreet where it's located and you might see that actually, it is pretty common to have a body like this. Western European and Nothern American norms and culture tells us it's ok to judge a big body, mercilessly. Wow. Unlike some other commentators, Dr. Nikki Stamp explains this issue very well in *The Guardian* in her piece ["Berating Nike for Plus Size Mannequin is no War on Obesity, It's just War on Bigger Bodies"](https://www.theguardian.com/commentisfree/2019/jun/12/berating-nike-for-plus-size-mannequins-is-no-war-on-obesity-its-just-war-on-bigger-bodies).

How did we get here? And more importantly, how do move on?

###Albrecht Dürer's synthesized ideal nudes
In the 15th and 16th century, Albrecht Dürer investigated Renaissance concepts of perspective and the right proportions of the human (nude) figure in his Four Books on Human Perception. Dürer's work is considered seminal in the field of art and foundational for the practice of life or figure drawing. His development of the “ideal nude” is the result of calculating the average of many bodies and synthesizing them into one body. John Berger explains in *Ways of Seeing*: 

> Dürer believed that the ideal nude ought to be constructed by taking the face of one body, the breasts of another, the legs of a third, the shoulders of a fourth, the hands of a fifth - and so on […T]he exercise presumed a remarkable indifference to who any one person really was. In the art-form of the European nude the painters and spectator-owners were usually men and the persons treated as objects, usually women (Berger 2008, p. 56-57).

![](https://upload.wikimedia.org/wikipedia/commons/thumb/a/a7/Albrecht_D%C3%BCrer_-_Studies_on_the_Proportions_of_the_Female_Body_-_WGA07263.jpg/364px-Albrecht_D%C3%BCrer_-_Studies_on_the_Proportions_of_the_Female_Body_-_WGA07263.jpg)

*Studies on the Proportions of the Female Body by Albrecht Dürer, 1528. Bamberg State Library. Image taken from Wikimedia commons.*

That's not a far cry from standardized sizing systems and even big data around the body. To measure = to know = to control. I don't want to take this direction even though I'll be using tools that allow me to take and use measurements of a 3D body scan immediately. 

### Standards and Deviants: the Measure of Man and Woman
> The average woman stands 160.5 cm tall and weighs 62.5 kg. The average man is 175.5 cm and weighs 78.4 kg. If these standards do not apply to you, you are not normal by design standards. 
 (Pater in *The Politics of Design*, p. 181). 
 
In his book *The Politics of Design*, Pater discusses designer Henry Dreyfuss's implementation of body measurements in product design on a large scale, which increased usability and safety of designed objects. His *The Measure of Man and Woman* (1959) is still a go-to textbook for design students, apparently. However, the data Dreyfus used was based on a dataset with measurements of young military men: quite a specific slice of the population.
 
Ruben Pater describes *standards* and standardized models of human bodies as being useful for mass production, but as also creating a false sense of truth: such as projecting only a binary view on gender (i.e. man *or* woman), ignoring other gender types suh as genderqueer, androgynous, transgender, agender and other gender identities. Often these models can be seen to be biased towards West European body types (Pater mentions e.g. average height of Bolivian females being 142.2cm compared to Dreyfus' standard of 160.5cm) or conversely, they are based on stereotypical and racialized representations.

**Caroline Criado-Perez wrote whole book about it!**<br>
In her book *Invisible Women: Exposing Data Bias in a World Designed for Men*, that came out in 2019, Criado-Perez describes an overload of design problems due to gender bias in the design world, from toilets to clothing to urban planning. Amazing book. Watch the video for a teaser relating to women's clothing and toilet use, then go buy the book. 

<iframe width="560" height="315" src="https://www.youtube-nocookie.com/embed/C6vAoD3HA9I?controls=0" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

## Experiment 1: MakeHuman - an interface critique
Sexualized and racialized bodily stereotypes still abound and not only in fashion and product design. The world of technology and software development echoes many of the stale ideas around the female bodies, able bodies and bodies of color. 

I did not go into history there, but started exploring this week's tools. I figured that asking some critical questions about the imagery in splash screens, and labels and classification systems used to structure and add meaning to interfaces of the software is worth mentioning as part of the research. Interfaces have politics too? I'd say they do, yes! And it's quite interesting to unravel. If you want to try it out: helpful list of prompts and provocations to confront an interface with is listed in [Hangar's Interface Manifesto](https://interfacemanifesto.hangar.org/index.php/Main_Page). I created a powerful fictitious woman figure with MakeHuman, and she proudly wears her women's sports wear crop top, but she isn't amused...

![](https://media.giphy.com/media/mBSb5MaP46sxtkdACO/giphy.gif)

*GIF by Loes Bogers via GIPHY, using screenshots of MakeHuman software*

**Imaginaries of the virtual** <br>
The splash screen of the *MakeHuman* software is a typical "virtual" fantasy of three fit and slender human figures, bodies that I would associate with my own 14-year old body. They are in an embrace where the arms of the left and right figure covers that of the middle one's breasts, who is facing the camera. They/she doesn't have primary sex organs however. Which aligns with the fact that after the splash screen, a trigger warning appears: be cautious as you might see bodies. And they might be..... NUDE! We would not want to offend anyone with unsollicited anatomical truthfulness. A correctness that the interface doesn't care so much about effectively as you will later have the option to blow up your avatars genitals as big as your fantasy requires. 

**Blumenbach's racial classification system, still here today**<br>
The interface also uses biological theorist Johann Friedrich Blumenbach's outdated and very problematic racial classification system from the 18th century. It's the one with categories like like "caucasian", and also the one underpinning the later pseudoscience *eugenics*. **News flash**: they're not real. They signify nothing besides an imagined superiority of Western European/American white folks: it's a construct created to divide. As an interface design alternative, one might just observe and describe the features themselves, rather than grouping them according to a system that perpetuates pejorative racial stereotypes. Find out more about it in this nice article: [Why Do We Keep Using the Word "Caucasian?" by Jolanda Moses](https://www.sapiens.org/column/race/caucasian-terminology-origin/)

**Your weight/body fat/breast size might be deemed off the charts**<br>
Each bodily feature can be adjusted with a scale (size of arms, proportions, muscle mass, facial recognition, body fat etc). It's worth considering where these extremes stop. There's a limit to how fat or skinny you may be apparently, even in 3D virtual world. 

**Gender stereotypes in avatar's outfits**<br>
Yup, they're there too. Go pick "women's sports outfit" and your avatar will be sporting a cropped top as leisure wear. Then look at the men's ones. 

Download *MakeHumanAngry* (made with MakeHuman) here:

<div class="sketchfab-embed-wrapper">
    <iframe title="A 3D model" width="400" height="200" src="https://sketchfab.com/models/c165c545d9bd4cd5866809f971c3c48d/embed?camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
    <a href="https://sketchfab.com/3d-models/angry-c165c545d9bd4cd5866809f971c3c48d?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">Angry</a>
    by <a href="https://sketchfab.com/loesjebo?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">loesjebo</a>
    on <a href="https://sketchfab.com?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">Sketchfab</a>
</p>
</div>


## Part 2: Beyond inert matter

What I personally find more interesting are studies that also acknowledge the fact that bodies act, they move, they morph, they change, they have agency. Capturing that can also tell us a lot about the body. 

**Étienne-Jules Marey and Eadward Muybridge's movement studies**<br>
I immediately think of Marey and Muybridge's movement studies from the early 19th century. Their research and methodologies are still so current. They were the first to study movement with the use of the then novel technology of photography. They studied for example the precise movements of birds in flight and horses galloping, that are hard to study with the human eye alone. Their images are famous and both actually also invented their own tools to do their studies, such as the [*sphygmograph*](https://en.wikipedia.org/wiki/Sphygmograph) (pulse meter wearable from 1863) and the [*chronophotographic gun*](https://en.wikipedia.org/wiki/%C3%89tienne-Jules_Marey), a high-speed camera from 1882. 

![](https://upload.wikimedia.org/wikipedia/commons/thumb/e/eb/Boys_playing_Leapfrog.jpg/440px-Boys_playing_Leapfrog.jpg)<br>
*Muybridge's Boys Playing Leapfrog 1883-1886, Wikimedia Commons*


What these two do quite interestingly is adding the factors of **time** and **space** to the capture of a body, rather than abstracting and decontextualizing it as if it existed in a vacuum. This is however still a rather positivist approach to understanding the body, that separates what can be known about the body from the experience of it. It also assumes that there is something of a god's perspective: an eye that can see at all times at ones, from all perspectives at once.

## Experiment 2: Time and Space in Rhino?
To try out some of these ideas, I went into Rhino to refamiliarize myself with this lovely toolbox. With which commands do I command my model into shape? Or rather, with which commands do I allow myself to see her anew? 

My model cultivates 1001 angles on herself to create a space for herself, enjoy herself and make her life manageable by lubricating intercultural communication, and (project a suggestion of) meeting the standards of herself, her son, housemates, friends, supervisor(s), neighbours, Danish friends and family, other Danish parents, herself, other English parents, English school staff, and so on. 

**Outcome: Multimom deserves a statue**

It sounds like this person deserves a statue for this. Here's what she looks like: 

<div class="sketchfab-embed-wrapper">
    <iframe title="A 3D model" width="400" height="200" src="https://sketchfab.com/models/73dbc0f8f4b8435b9719951812e66f0b/embed?autostart=1&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
    <a href="https://sketchfab.com/3d-models/multimomstatue-73dbc0f8f4b8435b9719951812e66f0b?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">Multimomstatue</a>
    by <a href="https://sketchfab.com/loesjebo?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">loesjebo</a>
    on <a href="https://sketchfab.com?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">Sketchfab</a>
</p>
</div>

**Manipulating the scan in Rhinoceros**<br>




##Measurements & Culture

Also, the way the body - and how it is captured and measured - is inscribed with culture is not addressed in Marey and Muybridge's work. For that we look elsewhere. 

### Orlan's MesuRAGEs
This artist does amazing work using her body as a material. In this series of art work, the artist measures streets or buildings using her own body physically and literally as a unit of measure: the ORLAN-corps, whilst raging against the male power that is represented in the way big institutions, like museums are built. 

<iframe width="560" height="315" src="https://www.youtube.com/embed/3F77c6sk95E" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

### Lucas Maassen's - Meten is Weten
Somewhat related is designer Lucas Maassen's workshop [Meten is Weten](https://educatie.hetnieuweinstituut.nl/workshops/meten-weten) at Nieuwe Instituut in Rotterdam in 2016 (I did not attend!), where he questions measuring systems with kids. A lot of measuring systems are historically based on the body (e.g. the measurement in *feet*), but where do they come from, and whose bodies are they based on? 

![](https://educatie.hetnieuweinstituut.nl/sites/default/files/styles/width_1024/public/dsc_3733_2000px.jpg?itok=iw2FckJW)>br?
*Photo by Petra van Ree*

### Experiment 3: Making my model less measurable

To allow her to be unruly, I thought to think of a technique that prevent her from being captured with standardized measuring systems with any precision. How could I abstract her in a truthful way, without re-presenting her with the kind of razorblade precision that measure-controls her down to the mm? 

## Ideas & inspiration

**My model is a rolemodel**<br>
The model for my mannequin, Alex is a super bright and wonderful person and friend, and also the mother of an amazing 8-year old boy. The way I've come to know her: she will only wear one label: that of *feminist killjoy* and she wears it with pride. I learn from her every day. She is able to create a welcoming space for everyone without making herself smaller for anyone, and I love that about her. That is why I want to model a torso based on her 3D scan that is fully lifesize, and not a mm smaller. 

I would like to capture what I perceive to be the essence of my friend, how she stands, how she carries her body, the volume of it, its strength as a whole, without necessarily replicating her exactly. There's a nice challenge in finding some abstraction without losing all the personality. Another reason is that her scan was made while wearing clothes and suspenders, which adds some details that are hard to recognize and therefor a bit distracting.

**Some inspiration**<br>
Love the abstracted futuristic models but they're all so skinny! What if the future were fuller? 

INSERT PINTEREST PINS

INSERT PICS FROM PRESENTATION

**Material use considerations**<br>
That said, I'd prefer not to go overboard creating this assignment, as it's unlikely I'll be *using* intensively, so I'll try to reduce the amount of materials required to produce the torso. The material provided by is 4-8 sheets of corrugated cardboard, with dimensions of 1160 X 960 cm and a thickness of 3mm.

Stacking slices makes for a nice solid mannequin with a lot of detail but easily eats up 10s of cardboard sheets. So you will see I've opted for the folded panels technique using Slicer (see below), and estimated I'd get better results using 300gms colored paper because it allows me to fold the vertices using tongue connections (see below). I got my go-to heavy duty paper: Florentino paper at Van Der Linde in Amsterdam. 

![](https://www.vanderlindewebshop.com/img/products/normal/florentino.jpg)

[Florentino 300gms at Van der Linde](https://www.vanderlindewebshop.com/nl/catalog/papier-karton/gekleurd-papier/van-der-linde-gekleurd-papier-en-karton/florentino-gekleurd-papier-300-grams/g+c+bg+a)


##Scanning with SizeStream

What I used for bodyscanning is the [SizeStream SS20 body scanner and software](http://sizestream.com/ss20-classic/) we have at work. Colleagues at the Fashion Research and Technology group use this machine to create a database of measurements to optimize e.g. the design of uniforms. The process of scanning is so straightforward, it's a bit silly to document, but here are the steps and below is a video that shows how it's done. Even the voice instruction and music you hear is really how the interface guides you lol.

* Step 0: find a model and ask them to step into the scanner and hold handle bars
* Step 1: open the software
* Step 2: press the big button to start scanning
* Step 3: wait until the lady sings and download your files in the program folder

<iframe width="560" height="315" src="https://www.youtube.com/embed/eyi-lCUl_w0?controls=0" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

**A scanner that takes your measurements** <br>
You get a 3D file and a textfile that holds the measurements defined in this particular software. The file is often not perfect, e.g. when somebody is moving during scanning or when they are wearing loosefitting clothes, or when they have a atypical body that is not delimited in the software's classification system. It will literally not recognize the person if they are not *standard* enough. Not much has changed since white privileged males their pencil-drawn studies of the human form: they are still preferred (near)-nude, as passive as possible and to not deviate from the norm. Unruly bodies ~~not welcome~~ I mean not accounted for. 

Fortunately things like the file can still be repaired. A far cry from healing from centuries of patriarchy, sexism and body shaming under the guise of building generalizable knowledge but hey. 

**Body language of the SizeStream**
What is kind of nice I think, is that it requires you to grab the handlebars next to your hips. I think it's a nice and strong position to take, not taking any notice of the kind of desirable positioning a male gaze might require, lol. This position also suits the personality and body language of my model quite well. 

**Repairing the 3D file**
I repaired my file using the [Netfabb Service](https://service.netfabb.com/service.php) where you can upload your .obj or .stl and it tracks down naked edges and messy meshes and repairs them so you can print your 3D file nicely if you wanted to. 



##Rhinoceros

###Basic manipulations

box, meshbooleandifference and meshbooleanintersection to chop off unwanted parts

how did Rhino work again?????

###Playing around

#### Rotating, multiple perspectives at once
dadadadaada

#### Abstracting
> Mesh > Mesh edit tools > Reduce mesh
95% still pretty good! Lost the face though

80%
reduced from 29952 to 5990 faces 
still pretty good!

99% 
reduced 29952 to 300 faces
nice and abstract! Lost the damaged foot though

Oh yeah I like this, let's go

## Slicer for the win

orientation wrong, changed to... z on import
click the rotation button at the top until you get it right

Input sizes of material, hmmmm. Choose technique etcetera first. Played around and settled on the folded panels

My pieces were wayyyy to big so I removed a lot of seams
Ended up with 6 sheets but the nesting algorithm isn't optimal, so did that manually in Illustrator and was able to fit them onto 4 sheets, and still make a lifesize mannequin.


## Illustrator

Nested all files in Illustrator
Use RGB to only cut the lines
I'll score lines manually, no dotted lines, not nice

# Cutting

Do a scale model for testing?

# Assembling

# Bonus







## Useful links

- [Jekyll](http://jekyll.org)
- [Google](http://google.com)
- [Markdown](https://en.wikipedia.org/wiki/Markdown)


## Gallery

![](../images/sample-photo.jpg)


## 3D Models


**Mannequin**

<div class="sketchfab-embed-wrapper">
    <iframe title="A 3D model" width="400" height="200" src="https://sketchfab.com/models/da7886cbd431414496b42399dcb04956/embed?autostart=1&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
    <a href="https://sketchfab.com/3d-models/mannequin-da7886cbd431414496b42399dcb04956?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">mannequin</a>
    by <a href="https://sketchfab.com/loesjebo?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">loesjebo</a>
    on <a href="https://sketchfab.com?utm_medium=embed&utm_source=website&utm_campaign=share-popup" target="_blank" style="font-weight: bold; color: #1CAAD9;">Sketchfab</a>
</p>
</div>


## References


Berger, John. *Ways of Seeing*, London: Penguin Books, Penguin Modern Classics, 2008 edition.

Criado-Perez, Caroline. *Invisible Women: Exposing Data Bias in a World Designed for Men*. Vintage Publishing, 2019.

"Interface Manifesto", *Hangar*, 2015: https://interfacemanifesto.hangar.org/index.php/Main_Page

Moses, Yolanda. "Why Do We Keep Using the Word 'Caucasian?', *Sapiens*, 1 February 2017: [https://www.sapiens.org/column/race/caucasian-terminology-origin/](https://www.sapiens.org/column/race/caucasian-terminology-origin/)

Pater, Ruben. *The Politics of Design*, Amsterdam: BIS Publishers, 2016.

Stamp, Nikki. "Berating Nike for plus-size mannequins is no war on obesity – it's just war on bigger bodies", *The Guardian*, 12 June 2019: [https://www.theguardian.com/commentisfree/2019/jun/12/berating-nike-for-plus-size-mannequins-is-no-war-on-obesity-its-just-war-on-bigger-bodies](https://www.theguardian.com/commentisfree/2019/jun/12/berating-nike-for-plus-size-mannequins-is-no-war-on-obesity-its-just-war-on-bigger-bodies)